<?php

# function mask_fields($list)
# {
#   $ret = array();
# 
#   foreach ($list as $field => $data)
#     $ret[] = $field;
# 
#   return $ret;
# }

function build_form($fields)
{
  $ret = array();

  $ret[] = '<div class="form">';
  $ret[] = '<form id="form_edit">';

  $ret[] = '<input type="hidden" id="edit_id" name="id" value="">';

  foreach ($fields as $id => $info) {
    if ($info['type'] == 'text') {
      $v = array('id="edit_'.$id.'"',
		 'name="'.$id.'"',
		 'size="'.$info['size'].'"',
		 'type="text"');
      $ret[] = sprintf('<label for="edit_%s"><b>%s</b></label><br>', $id, $info['name']);
      $ret[] = sprintf('<input %s><br>', implode(' ', $v));

    } elseif ($info['type'] == 'date') {
      error_log('type = date');
    }
  }

  $ret[] = '<div align="center"><button onclick="return form_save(this);">Speichern</button></div>';

  $ret[] = '</form>';
  $ret[] = '</div>';

  return $ret;
}

function build_grid($name, $mask)
{
  global $jscode;
  $ret = array();

  $jscode[] = 'Rico.writeDebugMsg = function(msg, resetFlag) {};';

  $opts = array("click: gridDrillDown",
		"menuEvent: 'contextmenu'",
		"highlightElem: 'menuRow'");

  if (array_key_exists('rows', $mask)) $opts[] = 'visibleRows: ' . $mask['rows'];
  if (array_key_exists('sort', $mask)) $opts[] = 'sortCol: ' . $mask['sort'];
  if ($mask['prefetch'] === false) $opts[] = 'prefetch: false';
  # $opts[] = 'frozenColumns: ' . count($mask['list']);
  $opts[] = 'saveColumnInfo: {width: true, filter: true, sort: true}';

  $ret[] = sprintf('<table id="grid_%s" class="ricoLiveGrid">', $name);
  $ret[] = '  <tr>';
  $specs = array();
  $fields = array();
  foreach ($mask['list'] as $field => $data) {
    $ret[] = sprintf('  <th>%s</th>', $data['name']);
    $s = array(sprintf("FieldName: 'input_%s'", $field),
	       sprintf("ColName: 'input_%s'", $data['name']));
    $s = array();
    if ($data['visible'] === false) $s[] = 'visible: false';
    if ($data['width'] > 0) $s[] = 'width: ' . $data['width'];
    if (array_key_exists('type', $data)) $s[] = "type: '" . $data['type'] . "'";
    if (array_key_exists('specs', $data)) $s[] = $data['specs'];
    $specs[] = '{' . implode(', ', $s) . '}';

    if (array_key_exists('sql', $data))
      $fields[] = $data['sql'] . ' AS ' . $field;
    else
      $fields[] = $field;
  }
  $_SESSION['grid_' . $name] = sprintf("SELECT %s FROM %s",
				       implode(',', $fields), $mask['table']);
  if (array_key_exists('join', $mask)) $_SESSION['grid_' . $name] .= ' JOIN ' . join(' JOIN ', $mask['join']);
  if (array_key_exists('where', $mask)) $_SESSION['grid_' . $name] .= ' WHERE ' . $mask['where'];

  $ret[] = '  </tr>';
  $ret[] = '</table>';

  $opts[] = 'columnSpecs: [' . implode(', ', $specs) . ']';

  if (strstr($opts[count($opts)-1], 'filterUI') !== false) $opts[] = 'FilterLocation: -1';

  $jscode[] = 'var grid;';
  $jscode[] = 'Rico.onLoad( function() {';
  $jscode[] = sprintf("var %s_opts = {\n  %s\n};", $name, implode(",\n  ", $opts));
  $jscode[] = sprintf("grid = new Rico.LiveGrid ('grid_%s', new Rico.Buffer.AjaxSQL('ajax/ricoXMLquery.php'), %s_opts);", $name, $name);
  $jscode[] = "grid.menu = new Rico.GridMenu();";
  $jscode[] = "grid.edit = new Rico.TableEdit(grid);";
  $jscode[] = '});';
  $jscode[] = "Rico.acceptLanguage('de-de,de;q=0.8,en;q=0.5,en-us;q=0.3');";
  $jscode[] = "Rico.loadModule('Effect','Calendar','LiveGridForms','LiveGridAjax','LiveGridMenu');";

  return $ret;
}

function build_details($name, $details)
{
  $ret = array();


  $ret[] = '<div class="box" id="details">';
  $ret[] = sprintf('<h3>%s</h3>', $details['title']);
  if (array_key_exists('subtitle', $details))
    $ret[] = sprintf('<p class="subtitle">%s</p>', $details['subtitle']);
  $ret[] = '<ul>';
  foreach ($details['list'] as $name => $info) {
    $ret[] = sprintf('<li>%s: <span id="detail_%s"></span></li>', $info['name'], $name);
  }
  $ret[] = '</ul>';
  $ret[] = '</div>';

  return $ret;
}

function build_mask($name, $mask)
{
  $grid = build_grid($name, $mask);

  if (array_key_exists('details', $mask))
    $details = build_details($name, $mask['details']);
  else
    $details = array();

  $title = $mask['title'];
  if (array_key_exists('subtitle', $mask))
    $title .= ' &ndash; ' . $mask['subtitle'];

  $head = array();
  $head[] = sprintf('<h3>%s</h3>', $title);
  $head[] = '<div class="right">';

  return array_merge($head,
		     $grid,
		     array('</div>','<div class="left">'),
		     $details,
		     array('</div>'));
}

function mask($name)
{
  global $jsfiles;
  global $mask;

  $ret = array();

  if (load_mask($name) === false)
    return;

  $jsfiles[] = 'lib/functions.js';
  $jsfiles[] = 'lib/rico/rico.js';

  if (array_key_exists('table',$mask) && array_key_exists('list',$mask))
    $ret = build_mask($name, $mask);

  if (array_key_exists('edit', $mask))
    $ret = array_merge($ret, build_form($mask['edit']));

  return implode("\n", $ret);
}

?>